@@ -24,6 +24,28 @@ class MySQLClient:
     def close(self):
         self.db.close()
 
+    def creat_table(self, name: str, field: list, close: bool = True):
+        '''
+        创建表
+        :param name 表名
+        :param field 字段列表，例：['id INT AUTO_INCREMENT PRIMARY KEY','name varchar(255)']
+        :return {bool} True/False
+        '''
+        result = False
+        sql = 'create table %s (%s)' % (name, (',').join(field))
+        print(sql)
+        try:
+            # 执行sql语句
+            self.cursor.execute(sql)
+            result = True
+        except:
+            # 如果发生错误则回滚
+            self.db.rollback()
+            result = False
+        if close:
+            self.close()
+        return result
+
     def insert(self, table: str, data: dict, close: bool = True):
         '''
         插入数据，插入的数据内容无需做特殊安全处理，方法内均进行了html转码保存数据
